

..
    Operations on coordinates
    [change columns as series: p.Start+=1000 ...]
    [... however there are more convenient methods: subsequence, spliced_sequence, extend]
    [after extend, show genome_bounds]

    A common operation on (multiple) pyranges regard overlaps. These are shown in the next page


    Overlapping and matching PyRanges
    ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

    [present different methods for different aims that all have to do with overlap: merge, cluster, subtract, join, count_overlaps ... . Start with a table summarizing differences: input, output].
    [add note: pandas merge: different!]


    Working at the transcript level
    ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

    [spliced_subsequence, subsequence, get_transcript_sequence,
    extend (to be developed with group_by),
    boundaries ,
    cumsum groupby as example

    ]


    Fetching external gene tracks
    ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

    [if pyranges_db is a thing, describe its uses here]


    RLEs: run length encodings
    ~~~~~~~~~~~~~~~~~~~~~~~~~~

    [outline as advanced usage. Put everything related to RLEs in a single chapter; keep as last even if you add further chapters]


